/** \file distribs.h
*/

#ifndef _D_MOD_DISTRIBS

#define _D_MOD_DISTRIBS
#define _D_VERSION_DISTRIBS 1.0.0

#ifndef M_PI
#define M_PI 3.14159265359
#endif

#ifndef M_PI_2
#define M_PI_2 1.57079632679
#endif

#ifndef M_2_PI
#define M_2_PI 0.636619772368
#endif

/**
 * It returns the seed used for the random numbers.
 * If it is the first function we call from the library it sets a new random seed 
 */
long distribs_get_seed(void);

/** Set a new seed */
void distribs_set_seed(long seed);

/** Returns a uniform random value in [0,1) */
double distribs_unif(void);

/** Returns a uniform random value in [initial,final) */
double distribs_uniform(double initial, double final);

/** Returns an exponentialy distributed random value with lambda = 1 */
double distribs_expon(void);

/** Returns an exponentialy distributed random value with parameter lambda */
double distribs_exponential(double lambda);

/** Returns a gaussian distributed random value with average 0 and standard deviation = 1, hence N(0,1)*/
double gauss(void);

/** Returns a gaussian distributed random value with average = mean and variance = var, hence N(mean,sqrt(var))*/
double distribs_gaussian(double mean, double var); /* parametros: media y varianza */

/** Returns an alpha-stable distributed random value with alpha=1, sigma=0, mu=0, hence S(1,0,0) */
double distribs_salfas1(double alfa);

/** Returns an alpha-stable distributed random value with alpha, sigma, mu and beta=0, hence S(1,0,0) */
double distribs_SalfaS(double alpha, double sigma, double mu);

/** Returns an alpha-stable distributed random value with alpha, sigma, mu and beta */
double distribs_stable(double alfa, double sigma, double beta, double mu);

/** Returns a Pareto distributed random value with parameters K and alpha */
double distribs_pareto(double K, double alfa);

/**
 * Returns a random value from a distribution discribed with its probability distribution function (argument "dist")
 * "dist" must be an array of couples of doubles (x,y), being points in the probability distribution
 * "numpoints" is the number of couples in the array "dist"
 */
double distribs_randFDP(double *dist, int numpoints); 

/** Returns a Weibull distributed random value with parameters alpha and beta */
double distribs_weibull(double alpha, double beta); /* Weibull */


#endif

